function []=GenerateRandomNumbers(seed,simParam_time,simParam_gyroVar)
% Generate random numbers and save to disk (to be used in Simulink
% simulation).
%
% --
% Supplementary material to:
% Sebastian Trimpe, "Stability Analysis of Distributed Event-Based State
% Estimation", IEEE Conference on Decision and Control (CDC), 2014.
%
% Copyright:
% Sebastian Trimpe
% Max-Planck-Institute for Intelligent Systems
% Autonomous Motion Department
% strimpe(at)tuebingen.mpg.de
%

% Revision history
% [14.09.14]   first version



%% Generate random numbers for simulation
% Generate numbers in Matlab, save in *.mat-file, read from Simulink
% simulation.

% Noise parameters
% All noise as uniform random number.
inputNoiseScale = 0.05;
gyroNoiseScale =  sqrt(3*simParam_gyroVar);

% Create multiple streams
% We need 4 streams: input noise (2 channels), gyro noise (1), random
% number for packet drop.
% [See Matlab doc for "Multiple streams".]
[s_u1, s_u2, s_gyro, s_drop] = RandStream.create('mlfg6331_64','NumStreams',4,'Seed',seed);


% Generate random numbers
Ts_ = 0.01;
K_sim = simParam_time/Ts_+1; % how many simulations steps? (sampling time = 0.01)

r_u1 = (2*rand(s_u1,K_sim,1)-1)*inputNoiseScale;
r_u2 = (2*rand(s_u2,K_sim,1)-1)*inputNoiseScale;
r_gyro = (2*rand(s_gyro,K_sim,1)-1)*gyroNoiseScale;
r_drop = rand(s_drop,K_sim,3);  % 3 measurements, i.e. 3 random numbers per step

% % Check: 
% corrcoef([r_u1,r_u2,r_gyro,r_drop]);

% Create data object for Simulink simulation
% [See Simulink help on "Uniform random number" block.]
kk = 0:Ts_:(K_sim-1)*Ts_;
data = [kk; r_u1'];
save temp_rand_u1.mat data;

data = [kk; r_u2'];
save temp_rand_u2.mat data;

data = [kk; r_gyro'];
save temp_rand_gyro.mat data;

data = [kk; r_drop'];
save temp_rand_drop.mat data;
